@@ -7,7 +7,7 @@
 
 #include "base_module_interface.h"
 
-const QString LOGIN_API_VERSION = "1.2.0";
+const QString LOGIN_API_VERSION = "2.0.0";
 
 namespace dss {
 namespace module {
@@ -22,11 +22,11 @@ enum AuthResult{
  * @brief 认证插件需要传回的数据
  */
 struct AuthCallbackData{
-    int result = AuthResult::None;          // 认证结果
-    std::string account; // 账户
-    std::string token;   // 令牌
-    std::string message; // 提示消息
-    std::string json;    // 预留数据
+    int result = AuthResult::None;  // 认证结果
+    QString account;                // 账户
+    QString token;                  // 令牌
+    QString message;                // 提示消息
+    QString json;                   // 预留数据
 };
 
 /**
@@ -52,18 +52,18 @@ enum DefaultAuthLevel {
  * 认证类型
  */
 enum AuthType {
-    AT_None = 0,                 // none
-    AT_Password = 1 << 0,        // 密码
-    AT_Fingerprint = 1 << 1,     // 指纹
-    AT_Face = 1 << 2,            // 人脸
-    AT_ActiveDirectory = 1 << 3, // AD域
-    AT_Ukey = 1 << 4,            // ukey
-    AT_FingerVein = 1 << 5,      // 指静脉
-    AT_Iris = 1 << 6,            // 虹膜
-    AT_PIN = 1 << 7,             // PIN
-    AT_PAM = 1 << 29,            // PAM
-    AT_Custom = 1 << 30,         // 自定义
-    AT_All = -1                  // all
+    AT_None            = 0,         // none
+    AT_Password        = 1 << 0,    // 密码
+    AT_Fingerprint     = 1 << 1,    // 指纹
+    AT_Face            = 1 << 2,    // 人脸
+    AT_ActiveDirectory = 1 << 3,    // AD域
+    AT_Ukey            = 1 << 4,    // ukey
+    AT_FingerVein      = 1 << 5,    // 指静脉
+    AT_Iris            = 1 << 6,    // 虹膜
+    AT_PIN             = 1 << 7,    // PIN
+    AT_PAM             = 1 << 29,   // PAM
+    AT_Custom          = 1 << 30,   // 自定义
+    AT_All             = -1         // all
 };
 
 /**
@@ -93,28 +93,15 @@ enum AuthState {
  * @param void * 登录器回传指针
  * void *: ContainerPtr
  */
-using AuthCallbackFun = void (*)(const AuthCallbackData *, void *);
+using AuthCallbackFunc = void (*)(const AuthCallbackData *, void *);
 
 /**
- * @brief 验证回调函数
- * @param const std::string & 发送给登录器的数据
- * @param void * 登录器回传指针
- *
- * @return 登录器返回的数据
- * @since 1.2.0
- *
- * 传入和传出的数据都是json格式的字符串，详见登录插件接口说明文档
+ * @brief 验证对象类型
  *
  */
-using MessageCallbackFun = std::string (*)(const std::string &, void *);
-
-/**
- * @brief 插件回调相关
- */
-struct LoginCallBack {
-    void *app_data; // 插件无需关注
-    AuthCallbackFun authCallbackFun;
-    MessageCallbackFun messageCallbackFunc;
+enum AuthObjectType {
+    LightDM,            // light display manager 显示管理器
+    DeepinAuthenticate  // deepin authenticate service 深度认证框架
 };
 
 class LoginModuleInterface : public BaseModuleInterface
@@ -127,31 +114,19 @@ public:
     ModuleType type() const override { return LoginType; }
 
     /**
-    * @brief 模块加载的类型
-    * @return LoadType
-    */
-    LoadType loadPluginType()  const override { return Load; }
-
-    /**
-     * @brief 模块图标的路径
-     * @return std::string
-     */
-    virtual std::string icon() const { return ""; }
-
-    /**
-     * @brief 设置回调函数 CallbackFun
-     */
-    virtual void setCallback(LoginCallBack *) = 0;
-
-    /**
-     * @brief 登录器通过此函数发送消息给插件，获取插件的状态或者信息，使用json格式字符串in&out数据，方便后期扩展和定制。
+     * @brief 设置回调验证回调函数，此函数会在init函数之前调用
      *
-     * @since 1.2.0
+     * @param AuthCallbackFunc 详见`AuthCallbackFunc`说明
+     *
+     * @since 2.0.0
      */
-    virtual std::string onMessage(const std::string &) { return "{}"; };
+    virtual void setAuthCallback(AuthCallbackFunc) = 0;
 
     /**
-     * @brief 重置插件
+     * @brief 插件需要在这个方法中重置UI和验证状态
+     * 调用时机：通常验证开始之前登录器会调用这个方法，但是不保证每次验证前都会调用。
+     *
+     * @since 2.0.0
      */
     virtual void reset() = 0;
 };
