@@ -13,6 +13,7 @@
 #include <DFloatingMessage>
 #include <DSuggestButton>
 #include <DMessageManager>
+#include <DAlertControl>
 
 #define Password_Auth QStringLiteral(":/misc/images/auth/password.svg")
 //const QString Password_Auth = ":/misc/images/auth/password.svg";
@@ -48,6 +49,7 @@ signals:
     void requestChangeFocus();                 // 切换焦点
     void requestShowKeyboardList();            // 显示键盘布局列表
     void resetPasswordMessageVisibleChanged(const bool isVisible);
+    void notifyLockedStateChanged(bool isLocked);
 
 public slots:
     void setResetPasswordMessageVisible(const bool isVisible);
@@ -65,6 +67,8 @@ private:
     void showPasswordHint();
     void setPasswordHintBtnVisible(const bool isVisible);
     bool isUserAccountBinded();
+    void showAlertMessage(const QString &text);
+    void hidePasswordHintWidget();
 
 private:
     DLabel *m_capsLock;             // 大小写状态
@@ -75,6 +79,7 @@ private:
     DFloatingMessage *m_resetPasswordFloatingMessage;
     uid_t m_currentUid; // 当前用户uid
     QTimer *m_bindCheckTimer;
+    DAlertControl *m_passwordHintWidget;
 };
 
 #endif // AUTHPASSWORD_H
