@@ -34,8 +34,8 @@ AuthWidget::AuthWidget(QWidget *parent)
     , m_userAvatar(nullptr)
     , m_expiredStateLabel(new DLabel(this))
     , m_expiredSpacerItem(new QSpacerItem(0, 0))
-    , m_nameLabel(nullptr)
     , m_accountEdit(nullptr)
+    , m_userNameWidget(nullptr)
     , m_capslockMonitor(nullptr)
     , m_keyboardTypeClip(nullptr)
     , m_singleAuth(nullptr)
@@ -71,30 +71,21 @@ void AuthWidget::initUI()
     m_userAvatar->setFocusPolicy(Qt::NoFocus);
     m_userAvatar->setIcon(m_user->avatar());
     m_userAvatar->setAvatarSize(UserAvatar::AvatarLargeSize);
-    /* 用户名 */
-    m_nameLabel = new DLabel(this);
-    m_nameLabel->setAccessibleName(QStringLiteral("NameLabel"));
-    m_nameLabel->setTextFormat(Qt::TextFormat::PlainText);
-    m_nameLabel->setText(m_model->currentUser()->displayName());
-    m_nameLabel->setAlignment(Qt::AlignCenter);
-    m_nameLabel->setTextFormat(Qt::TextFormat::PlainText);
-    DFontSizeManager::instance()->bind(m_nameLabel, DFontSizeManager::T2);
-    QPalette palette = m_nameLabel->palette();
-    palette.setColor(QPalette::WindowText, Qt::white);
-    m_nameLabel->setPalette(palette);
     /* 用户名输入框 */
     m_accountEdit = new DLineEditEx(this);
     m_accountEdit->setContextMenuPolicy(Qt::NoContextMenu);
     m_accountEdit->lineEdit()->setAlignment(Qt::AlignCenter);
     m_accountEdit->setClearButtonEnabled(false);
     m_accountEdit->setPlaceholderText(tr("Account"));
+    // 用户名
+    m_userNameWidget = new UserNameWidget(true, this);
     /* 密码过期提示 */
     m_expiredStateLabel->setAccessibleName("ExpiredStateLabel");
     m_expiredStateLabel->setWordWrap(true);
     m_expiredStateLabel->setAlignment(Qt::AlignHCenter);
     m_expiredStateLabel->hide();
     /* 解锁按钮 */
-    m_lockButton = new DFloatingButton(this);
+    m_lockButton = new TransparentButton(this);
     if (m_model->appType() == Lock) {
         m_lockButton->setIcon(DStyle::SP_LockElement);
     } else {
@@ -116,7 +107,7 @@ void AuthWidget::initConnections()
         setLockButtonType(action);
     });
     /* 用户名 */
-    connect(qGuiApp, &QGuiApplication::fontChanged, this, &AuthWidget::updateUserNameLabel);
+    connect(qGuiApp, &QGuiApplication::fontChanged, this, &AuthWidget::updateUserDisplayNameLabel);
     /* 用户名输入框 */
     connect(m_accountEdit, &DLineEditEx::returnPressed, this, [this] {
         if (m_accountEdit->isVisible() && !m_accountEdit->text().isEmpty()) {
@@ -154,25 +145,24 @@ void AuthWidget::setUser(std::shared_ptr<User> user)
     m_connectionList.clear();
     m_user = user;
     m_connectionList << connect(user.get(), &User::avatarChanged, this, &AuthWidget::setAvatar)
-                     << connect(user.get(), &User::displayNameChanged, this, &AuthWidget::updateUserNameLabel)
+                     << connect(user.get(), &User::displayNameChanged, this, &AuthWidget::updateUserDisplayNameLabel)
                      << connect(user.get(), &User::passwordHintChanged, this, &AuthWidget::setPasswordHint)
                      << connect(user.get(), &User::limitsInfoChanged, this, &AuthWidget::setLimitsInfo)
-                     << connect(user.get(), &User::passwordExpiredInfoChanged, this, &AuthWidget::updatePasswordExpiredState)
-                     << connect(user.get(), &User::limitsInfoChangedString, this, &AuthWidget::setLimitsInfoString);
+                     << connect(user.get(), &User::passwordExpiredInfoChanged, this, &AuthWidget::updatePasswordExpiredState);
 
     setAvatar(user->avatar());
     setPasswordHint(user->passwordHint());
     setLimitsInfo(user->limitsInfo());
     updatePasswordExpiredState();
-    updateUserNameLabel();
+    updateUserDisplayNameLabel();
 
     /* 根据用户类型设置用户名和用户名输入框的可见性 */
     if (user->type() == User::Default) {
-        m_nameLabel->hide();
+        m_userNameWidget->hide();
         m_accountEdit->show();
         m_accountEdit->setFocus();
     } else {
-        m_nameLabel->show();
+        m_userNameWidget->show();
         m_accountEdit->hide();
         m_accountEdit->clear();
     }
@@ -280,16 +270,9 @@ void AuthWidget::setLimitsInfo(const QMap<int, User::LimitsInfo> *limitsInfo)
         }
         ++i;
     }
-}
 
-/**
- * @brief 认证设置信息发给插件
- * @param limitsInfoStr
- */
-void AuthWidget::setLimitsInfoString(const QString &limitsInfoStr)
-{
     if (m_customAuth) {
-        m_customAuth->setLimitsInfo(limitsInfoStr);
+        m_customAuth->setLimitsInfo(*limitsInfo);
     }
 }
 
@@ -306,18 +289,10 @@ void AuthWidget::setAvatar(const QString &avatar)
  * @brief 设置用户名字体
  * @param font
  */
-void AuthWidget::updateUserNameLabel()
+void AuthWidget::updateUserDisplayNameLabel()
 {
-    const QString &name = m_user->displayName();
-    int nameWidth = m_nameLabel->fontMetrics().boundingRect(name).width();
-    int labelMaxWidth = width() - 10 * 2;
-
-    if (nameWidth > labelMaxWidth) {
-        QString str = m_nameLabel->fontMetrics().elidedText(name, Qt::ElideRight, labelMaxWidth);
-        m_nameLabel->setText(str);
-    } else {
-        m_nameLabel->setText(name);
-    }
+    m_userNameWidget->updateFullName(m_user->fullName());
+    m_userNameWidget->updateUserName(m_user->name());
 }
 
 /**
@@ -358,6 +333,10 @@ void AuthWidget::setLockButtonType(const int type)
         }
         break;
     }
+
+    // 按钮不可用时颜色还是使用活动色，然后需要40%透明
+    QColor color = lockPalette.color(QPalette::Active, QPalette::Highlight);
+    lockPalette.setColor(QPalette::Disabled, QPalette::Highlight, color);
     m_lockButton->setPalette(lockPalette);
 }
 
@@ -513,8 +492,7 @@ void AuthWidget::showEvent(QShowEvent *event)
 int AuthWidget::getTopSpacing() const
 {
     const int topHeight = static_cast<int>(topLevelWidget()->geometry().height() * AUTH_WIDGET_TOP_SPACING_PERCENT);
-    const int deltaY = topHeight - calcCurrentHeight(LOCK_CONTENT_TOP_WIDGET_HEIGHT)
-            - calcCurrentHeight(LOCK_CONTENT_CENTER_LAYOUT_MARGIN);
+    const int deltaY = topHeight - calcCurrentHeight(LOCK_CONTENT_CENTER_LAYOUT_MARGIN);
 
     return qMax(15, deltaY);
 }
