@@ -6,12 +6,14 @@
 #define AUTHWIDGET_H
 
 #include "userinfo.h"
+#include "user_name_widget.h"
 
 #include <DArrowRectangle>
 #include <DBlurEffectWidget>
 #include <DClipEffectWidget>
 #include <DFloatingButton>
 #include <DLabel>
+#include <DStyleOptionButton>
 
 #include <QWidget>
 
@@ -31,6 +33,33 @@ class UserAvatar;
 
 DWIDGET_USE_NAMESPACE
 
+class TransparentButton : public DFloatingButton
+{
+    Q_OBJECT
+
+public:
+    explicit TransparentButton(QWidget *parent = nullptr)
+        : DFloatingButton (parent) {
+
+    };
+
+protected:
+    void paintEvent(QPaintEvent *event) override {
+        Q_UNUSED(event)
+
+        // 按钮不可用时颜色还是使用活动色，然后需要40%透明
+        DStylePainter p(this);
+        DStyleOptionButton opt;
+        initStyleOption(&opt);
+        if (isEnabled()) {
+            p.setOpacity(1.0);
+        } else {
+            p.setOpacity(0.4);
+        }
+        p.drawControl(DStyle::CE_IconButton, opt);
+    };
+};
+
 class AuthWidget : public QWidget
 {
     Q_OBJECT
@@ -68,9 +97,8 @@ protected:
 
     void setUser(std::shared_ptr<User> user);
     void setLimitsInfo(const QMap<int, User::LimitsInfo> *limitsInfo);
-    void setLimitsInfoString(const QString &limitsInfoStr);
     void setAvatar(const QString &avatar);
-    void updateUserNameLabel();
+    void updateUserDisplayNameLabel();
     void setPasswordHint(const QString &hint);
     void setLockButtonType(const int type);
 
@@ -94,13 +122,13 @@ protected:
     FrameDataBind *m_frameDataBind;
 
     DBlurEffectWidget *m_blurEffectWidget; // 模糊背景
-    DFloatingButton *m_lockButton;         // 解锁按钮
+    TransparentButton *m_lockButton;         // 解锁按钮
     UserAvatar *m_userAvatar;              // 用户头像
 
     DLabel *m_expiredStateLabel;           // 密码过期提示
     QSpacerItem *m_expiredSpacerItem;      // 密码过期提示与按钮的间隔
-    DLabel *m_nameLabel;          // 用户名
     DLineEditEx *m_accountEdit;   // 用户名输入框
+    UserNameWidget *m_userNameWidget;    // 用户名
 
     KeyboardMonitor *m_capslockMonitor;    // 大小写
     DClipEffectWidget *m_keyboardTypeClip; // 键盘布局类型菜单边界裁剪类
