@@ -108,9 +108,6 @@ void LockContent::initConnections()
         emit requestEndAuthentication(m_model->currentUser()->name(), AT_All);
     });
     connect(m_controlWidget, &ControlWidget::requestShutdown, this, [ = ] {
-        if (m_model->appType() == AuthCommon::Lock)
-            m_model->powerBtnPressedFromLock();
-
         m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PowerMode);
     });
     connect(m_controlWidget, &ControlWidget::requestSwitchVirtualKB, this, &LockContent::toggleVirtualKB);
@@ -119,7 +116,7 @@ void LockContent::initConnections()
     //刷新背景单独与onStatusChanged信号连接，避免在showEvent事件时调用onStatusChanged而重复刷新背景，减少刷新次数
     connect(m_model, &SessionBaseModel::onStatusChanged, this, &LockContent::onStatusChanged);
 
-    //在锁屏显示时，启动onborad进程，锁屏结束时结束onboard进程
+    // 在锁屏显示时，启动onborad进程，锁屏结束时结束onboard进程
     auto initVirtualKB = [&](bool hasvirtualkb) {
         if (hasvirtualkb && !m_virtualKB) {
             connect(&VirtualKBInstance::Instance(), &VirtualKBInstance::initFinished, this, [&] {
@@ -142,7 +139,7 @@ void LockContent::initConnections()
         isMFA ? initMFAWidget() : initSFAWidget();
         // 当前中间窗口为空或者中间窗口就是验证窗口的时候显示验证窗口
         if (!m_centerWidget || m_centerWidget == m_authWidget)
-            setCenterContent(m_authWidget, 0, Qt::AlignTop, m_authWidget->getTopSpacing());
+            setCenterContent(m_authWidget, 0, Qt::AlignTop, calcTopSpacing(m_authWidget->getTopSpacing()));
     });
 
     connect(m_wmInter, &__wm::WorkspaceSwitched, this, &LockContent::currentWorkspaceChanged);
@@ -205,7 +202,8 @@ void LockContent::initSFAWidget()
     connect(m_sfaWidget, &SFAWidget::requestCheckAccount, this, &LockContent::requestCheckAccount);
     connect(m_sfaWidget, &SFAWidget::authFinished, this, &LockContent::authFinished);
     connect(m_sfaWidget, &SFAWidget::updateParentLayout, this, [this] {
-        m_centerSpacerItem->changeSize(0, m_sfaWidget->getTopSpacing());
+        m_centerSpacerItem->changeSize(0, calcTopSpacing(m_sfaWidget->getTopSpacing()));
+        m_centerVLayout->invalidate();
     });
 }
 
@@ -251,7 +249,7 @@ void LockContent::onCurrentUserChanged(std::shared_ptr<User> user)
 
 void LockContent::pushPasswordFrame()
 {
-    setCenterContent(m_authWidget, 0, Qt::AlignTop, m_authWidget->getTopSpacing());
+    setCenterContent(m_authWidget, 0, Qt::AlignTop, calcTopSpacing(m_authWidget->getTopSpacing()));
 
     m_authWidget->syncResetPasswordUI();
 }
@@ -267,7 +265,7 @@ void LockContent::pushUserFrame()
 
 void LockContent::pushConfirmFrame()
 {
-    setCenterContent(m_authWidget, 0, Qt::AlignTop, m_authWidget->getTopSpacing());
+    setCenterContent(m_authWidget, 0, Qt::AlignTop, calcTopSpacing(m_authWidget->getTopSpacing()));
 }
 
 void LockContent::pushShutdownFrame()
@@ -298,7 +296,7 @@ void LockContent::onNewConnection()
 
     // 重置密码程序启动连接成功锁屏界面才释放键盘，避免点击重置密码过程中使用快捷键切走锁屏
     if (window()->windowHandle() && window()->windowHandle()->setKeyboardGrabEnabled(false)) {
-        qDebug() << "setKeyboardGrabEnabled(false) success！";
+        qDebug() << "setKeyboardGrabEnabled(false) success!";
     }
 
     if (m_localServer->hasPendingConnections()) {
@@ -383,11 +381,6 @@ void LockContent::mouseReleaseEvent(QMouseEvent *event)
         emit requestSwitchToUser(m_model->currentUser());
     }
 
-    if (m_model->currentModeState() == SessionBaseModel::ShutDownMode
-        || m_model->currentModeState() == SessionBaseModel::PowerMode) {
-        m_model->resetPowerBtnPressedFromLock();
-    }
-
     m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
 
     SessionBaseWindow::mouseReleaseEvent(event);
@@ -415,8 +408,8 @@ void LockContent::resizeEvent(QResizeEvent *event)
     });
 
     if (SessionBaseModel::PasswordMode == m_model->currentModeState() || (SessionBaseModel::ConfirmPasswordMode == m_model->currentModeState())) {
-        m_centerSpacerItem->changeSize(0, m_authWidget->getTopSpacing());
-        m_centerVLayout->update();
+        m_centerSpacerItem->changeSize(0, calcTopSpacing(m_authWidget->getTopSpacing()));
+        m_centerVLayout->invalidate();
     }
 
     SessionBaseWindow::resizeEvent(event);
@@ -630,11 +623,6 @@ void LockContent::keyPressEvent(QKeyEvent *event)
         }
         break;
     case Qt::Key_Escape:
-        if (m_model->currentModeState() == SessionBaseModel::ShutDownMode
-            || m_model->currentModeState() == SessionBaseModel::PowerMode) {
-            m_model->resetPowerBtnPressedFromLock();
-        }
-
         if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ConfirmPasswordMode) {
             m_model->setAbortConfirm(false);
             m_model->setPowerAction(SessionBaseModel::PowerAction::None);
