@@ -29,7 +29,6 @@ SessionBaseModel::SessionBaseModel(QObject *parent)
     , m_allowShowCustomUser(false)
     , m_SEOpen(false)
     , m_isUseWayland(QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive))
-    , m_pressedPowerBtnFromLock(false)
     , m_appType(AuthCommon::None)
     , m_currentUser(nullptr)
     , m_lastLogoutUser(nullptr)
@@ -241,16 +240,6 @@ void SessionBaseModel::setAllowShowCustomUser(const bool allowShowCustomUser)
     m_allowShowCustomUser = allowShowCustomUser;
 }
 
-void SessionBaseModel::powerBtnPressedFromLock()
-{
-    m_pressedPowerBtnFromLock = true;
-}
-
-void SessionBaseModel::resetPowerBtnPressedFromLock()
-{
-    m_pressedPowerBtnFromLock = false;
-}
-
 /**
  * @brief 认证类型
  *
