@@ -26,6 +26,7 @@
 
 const QSize AuthButtonSize(60, 36);
 const QSize AuthButtonIconSize(24, 24);
+const int MAIN_LAYOUT_SPACING = 10;
 
 QList<SFAWidget*> SFAWidget::SFAWidgetObjs = {};
 
@@ -36,8 +37,8 @@ SFAWidget::SFAWidget(QWidget *parent)
     , m_biometricAuthState(nullptr)
     , m_retryButton(new DFloatingButton(this))
     , m_bioAuthStatePlaceHolder(new QSpacerItem(0, BIO_AUTH_STATE_PLACE_HOLDER_HEIGHT))
-    , m_bioBottomSpacingHolder(new QSpacerItem(0, BIO_AUTH_STATE_BOTTOM_SPACING))
-    , m_authTypeBottomSpacingHolder(new QSpacerItem(0, CHOOSE_AUTH_TYPE_BUTTON_BOTTOM_SPACING))
+    , m_bioBottomSpacingHolder(new QSpacerItem(0, calcCurrentHeight(BIO_AUTH_STATE_BOTTOM_SPACING)))
+    , m_authTypeBottomSpacingHolder(new QSpacerItem(0, calcCurrentHeight(CHOOSE_AUTH_TYPE_BUTTON_BOTTOM_SPACING)))
     , m_currentAuthType(AT_All)
     , m_inited(false)
 {
@@ -78,14 +79,14 @@ void SFAWidget::initUI()
     m_retryButton->hide();
 
     m_mainLayout->setContentsMargins(10, 0, 10, 0);
-    m_mainLayout->setSpacing(10);
+    m_mainLayout->setSpacing(MAIN_LAYOUT_SPACING);
     m_mainLayout->addWidget(m_biometricAuthState, 0, Qt::AlignCenter);
     m_mainLayout->addItem(m_bioAuthStatePlaceHolder);
     m_mainLayout->addItem(m_bioBottomSpacingHolder);
     m_mainLayout->addWidget(m_chooseAuthButtonBox, 0, Qt::AlignCenter);
     m_mainLayout->addItem(m_authTypeBottomSpacingHolder);
     m_mainLayout->addWidget(m_userAvatar);
-    m_mainLayout->addWidget(m_nameLabel, 0, Qt::AlignVCenter);
+    m_mainLayout->addWidget(m_userNameWidget, 0, Qt::AlignVCenter);
     m_mainLayout->addWidget(m_accountEdit, 0, Qt::AlignVCenter);
     m_mainLayout->addSpacing(10);
     m_mainLayout->addWidget(m_expiredStateLabel);
@@ -127,8 +128,7 @@ void SFAWidget::setAuthType(const int type)
 {
     qDebug() << Q_FUNC_INFO << "SFAWidget::setAuthType:" << type;
     int authType = type;
-    if (dss::module::ModulesLoader::instance().findModulesByType(dss::module::BaseModuleInterface::LoginType).size() > 0
-            && !m_model->currentUser()->isNoPasswordLogin() && !m_model->currentUser()->isAutomaticLogin()) {
+    if (useCustomAuth()) {
         authType |= AT_Custom;
         initCustomAuth();
 
@@ -138,13 +138,11 @@ void SFAWidget::setAuthType(const int type)
         // TODO 每个屏幕只创建一个LockContent，鼠标在屏幕间移动的时候重新设置LockContent的parent即可。
         qInfo() << "Sfa is inited: " << m_inited << ", sfa widgets size: " << SFAWidgetObjs.size();
         if (m_inited || SFAWidgetObjs.size() <= 1) {
-             qInfo() << Q_FUNC_INFO << "m_customAuth->authType()" << m_customAuth->authType();
-            if (m_customAuth->defaultAuthLevel() == AuthCommon::DefaultAuthLevel::Default) {
+            qInfo() << Q_FUNC_INFO << "m_customAuth->authType()" << m_customAuth->authType();
+            if (m_customAuth->pluginConfig().defaultAuthLevel == AuthCommon::DefaultAuthLevel::Default) {
                 m_currentAuthType = m_currentAuthType == AT_All ? AT_Custom : m_currentAuthType;
-            } else if (m_customAuth->defaultAuthLevel() == AuthCommon::DefaultAuthLevel::StrongDefault) {
-                if (m_currentAuthType == AT_All || m_currentAuthType == AT_Custom) {
-                    m_currentAuthType = m_customAuth->authType();
-                }
+            } else if (m_customAuth->pluginConfig().defaultAuthLevel == AuthCommon::DefaultAuthLevel::StrongDefault) {
+                m_currentAuthType = AT_Custom;
             }
         }
 
@@ -160,12 +158,10 @@ void SFAWidget::setAuthType(const int type)
         m_frameDataBind->clearValue("SFCustomAuthMsg");
 
         // fix152437，避免初始化其他认证方式图像和nameLabel为隐藏
-        if (!m_userAvatar->isVisible())
-            m_userAvatar->setVisible(true);
-        if (!m_nameLabel->isVisible())
-            m_nameLabel->setVisible(true);
-        if (!m_lockButton->isVisible())
-            m_lockButton->setVisible(true);
+        m_userAvatar->setVisible(true);
+        m_lockButton->setVisible(true);
+        if (m_user->type() != User::Default)
+            m_userNameWidget->setVisible(true);
     }
 
     if (type != AT_None || !m_customAuth || m_user->type() != User::Default) {
@@ -238,7 +234,14 @@ void SFAWidget::setAuthType(const int type)
         m_frameDataBind->clearValue("SFSingleAuthMsg");
     }
 
-    m_chooseAuthButtonBox->setEnabled(true);
+    if (AppType::Login == m_model->appType() && m_passwordAuth) {
+        m_chooseAuthButtonBox->setEnabled(!m_passwordAuth->isLocked());
+        if (m_passwordAuth->isLocked()) {
+            m_user->setLastAuthType(AT_Password);
+            m_currentAuthType = AT_Password;
+        }
+    }
+
     const int count = m_authButtons.values().size();
     if (count > 0) {
         m_chooseAuthButtonBox->setButtonList(m_authButtons.values(), true);
@@ -286,7 +289,7 @@ void SFAWidget::setAuthType(const int type)
         m_chooseAuthButtonBox->hide();
     }
 
-    if (m_customAuth && !m_customAuth->showSwithButton()) {
+    if (m_customAuth && !m_customAuth->pluginConfig().showSwitchButton) {
         m_chooseAuthButtonBox->button(AT_Custom)->hide();
         if (count <= 2)
             m_chooseAuthButtonBox->hide();
@@ -353,12 +356,12 @@ void SFAWidget::setAuthState(const int type, const int state, const QString &mes
             m_frameDataBind->updateValue("SFSingleAuthMsg", message);
         }
 
-        // 这里是为了让自定义登陆知道ligthdm已经开启验证了
+        // 这里是为了让自定义登陆知道lightdm已经开启验证了
         qInfo() << "Current auth type is: " << m_currentAuthType;
         if (m_customAuth && state == AS_Prompt && m_currentAuthType == AT_Custom) {
             // 有可能DA发送了验证开始，但是lightdm的验证还未开始，此时发送token的话lightdm无法验证通过。
-            // ligthdm的pam发送prompt后则认为lightdm的pam已经开启验证
-            qInfo() << "Greeter is in authentication";
+            // lightdm的pam发送prompt后则认为lightdm验证已经开始
+            qInfo() << "LightDM is in authentication right now";
             m_customAuth->lightdmAuthStarted();
         }
         break;
@@ -395,9 +398,7 @@ void SFAWidget::initSingleAuth()
     replaceWidget(m_singleAuth);
     m_frameDataBind->updateValue("SFAType", AT_PAM);
 
-    connect(m_singleAuth, &AuthSingle::activeAuth, this, [ this ] {
-        emit requestStartAuthentication(m_model->currentUser()->name(), AT_PAM);
-    });
+    connect(m_singleAuth, &AuthSingle::activeAuth, this, &SFAWidget::onActiveAuth);
     connect(m_singleAuth, &AuthSingle::authFinished, this, [this](const int authState) {
         if (authState == AS_Success) {
             m_user->setLastAuthType(AT_PAM);
@@ -469,9 +470,7 @@ void SFAWidget::initPasswdAuth()
     m_passwordAuth->setCurrentUid(m_model->currentUser()->uid());
     m_passwordAuth->hide();
 
-    connect(m_passwordAuth, &AuthPassword::activeAuth, this, [this] {
-        emit requestStartAuthentication(m_user->name(), AT_Password);
-    });
+    connect(m_passwordAuth, &AuthPassword::activeAuth, this, &SFAWidget::onActiveAuth);
     connect(m_passwordAuth, &AuthPassword::authFinished, this, [this](const int authState) {
         checkAuthResult(AT_Password, authState);
     });
@@ -486,6 +485,16 @@ void SFAWidget::initPasswdAuth()
         m_lockButton->setEnabled(false);
         emit sendTokenToAuth(m_user->name(), AT_Password, text);
     });
+
+    if (AppType::Login == m_model->appType()) {
+        connect(m_passwordAuth, &AuthPassword::notifyLockedStateChanged, this, [this] (bool isLocked) {
+            m_chooseAuthButtonBox->setEnabled(!isLocked);
+            if (isLocked) {
+                onRequestChangeAuth(AT_Password);
+            }
+        });
+    }
+
     connect(m_lockButton, &QPushButton::clicked, m_passwordAuth, &AuthPassword::requestAuthenticate);
     connect(m_capslockMonitor, &KeyboardMonitor::capslockStatusChanged, m_passwordAuth, &AuthPassword::setCapsLockVisible);
     /* 输入框数据同步 */
@@ -544,9 +553,7 @@ void SFAWidget::initFingerprintAuth()
     m_fingerprintAuth->setAuthFactorType(DDESESSIONCC::SingleAuthFactor);
     m_fingerprintAuth->setAuthStateLabel(m_biometricAuthState);
 
-    connect(m_fingerprintAuth, &AuthFingerprint::activeAuth, this, [this] {
-        emit requestStartAuthentication(m_model->currentUser()->name(), AT_Fingerprint);
-    });
+    connect(m_fingerprintAuth, &AuthFingerprint::activeAuth, this, &SFAWidget::onActiveAuth);
     connect(m_fingerprintAuth, &AuthFingerprint::authFinished, this, [this](const int authState) {
         checkAuthResult(AT_Fingerprint, authState);
     });
@@ -586,9 +593,7 @@ void SFAWidget::initUKeyAuth()
     m_ukeyAuth = new AuthUKey(this);
     m_ukeyAuth->hide();
 
-    connect(m_ukeyAuth, &AuthUKey::activeAuth, this, [this] {
-        emit requestStartAuthentication(m_model->currentUser()->name(), AT_Ukey);
-    });
+    connect(m_ukeyAuth, &AuthUKey::activeAuth, this, &SFAWidget::onActiveAuth);
     connect(m_ukeyAuth, &AuthUKey::authFinished, this, [this](const int authState) {
         checkAuthResult(AT_Ukey, authState);
     });
@@ -657,9 +662,7 @@ void SFAWidget::initFaceAuth()
         onRetryButtonVisibleChanged(false);
         emit requestStartAuthentication(m_model->currentUser()->name(), AT_Face);
     });
-    connect(m_faceAuth, &AuthFace::activeAuth, this, [this] {
-        emit requestStartAuthentication(m_model->currentUser()->name(), AT_Face);
-    });
+    connect(m_faceAuth, &AuthFace::activeAuth, this, &SFAWidget::onActiveAuth);
     connect(m_faceAuth, &AuthFace::authFinished, this, [this](const int authState) {
         checkAuthResult(AT_Face, authState);
     });
@@ -719,9 +722,7 @@ void SFAWidget::initIrisAuth()
         onRetryButtonVisibleChanged(false);
         emit requestStartAuthentication(m_model->currentUser()->name(), AT_Iris);
     });
-    connect(m_irisAuth, &AuthIris::activeAuth, this, [ this ] {
-        emit requestStartAuthentication(m_model->currentUser()->name(), AT_Iris);
-    });
+    connect(m_irisAuth, &AuthIris::activeAuth, this, &SFAWidget::onActiveAuth);
     connect(m_irisAuth, &AuthIris::authFinished, this, [this](const int authState) {
         checkAuthResult(AT_Iris, authState);
     });
@@ -793,7 +794,7 @@ void SFAWidget::initCustomAuth()
         if (m_user && m_user->name() == account) {
             dss::module::AuthCallbackData data = m_customAuth->getCurrentAuthData();
             if (data.result == dss::module::Success)
-                Q_EMIT sendTokenToAuth(m_user->name(), AT_Custom, QString::fromStdString(data.token));
+                Q_EMIT sendTokenToAuth(m_user->name(), AT_Custom, data.token);
             else
                 qWarning() << Q_FUNC_INFO << "auth failed";
 
@@ -807,7 +808,7 @@ void SFAWidget::initCustomAuth()
 
     /* 认证选择按钮 */
     DButtonBoxButton *btn = new DButtonBoxButton(DStyle::SP_SelectElement, QString(), this);
-    const QString &iconStr = QString::fromStdString(module->icon());
+    const QString &iconStr = module->icon();
     const QIcon icon = QFile::exists(iconStr) ? QIcon(iconStr) : QIcon::fromTheme(iconStr);
     if (!icon.isNull()) {
         btn->setIcon(icon);
@@ -822,20 +823,20 @@ void SFAWidget::initCustomAuth()
             m_biometricAuthState->hide();
             setBioAuthStateVisible(nullptr, false);
             m_accountEdit->hide();
-            m_userAvatar->setVisible(m_customAuth->showAvatar());
-            m_nameLabel->setVisible(m_customAuth->showUserName());
-            m_lockButton->setVisible(m_customAuth->showLockButton());
+            m_userAvatar->setVisible(m_customAuth->pluginConfig().showAvatar);
+            m_userNameWidget->setVisible(m_customAuth->pluginConfig().showUserName);
+            m_lockButton->setVisible(m_customAuth->pluginConfig().showLockButton);
             replaceWidget(m_customAuth);
             m_frameDataBind->updateValue("SFAType", AT_Custom);
             Q_EMIT requestStartAuthentication(m_user->name(), AT_Custom);
         } else {
             m_customAuth->hide();
-            m_nameLabel->show();
+            m_userNameWidget->show();
             m_userAvatar->show();
             m_lockButton->show();
             m_lockButton->setEnabled(false);
             if (m_user->type() == User::Default) {
-                m_nameLabel->hide();
+                m_userNameWidget->hide();
                 m_accountEdit->show();
                 m_accountEdit->setFocus();
             }
@@ -891,7 +892,7 @@ void SFAWidget::syncAuthType(const QVariant &value)
     QAbstractButton *btn = m_chooseAuthButtonBox->button(value.toInt());
     if (btn) {
         btn->setChecked(true);
-        if (authType == AT_Custom && m_customAuth && !m_customAuth->showSwithButton()) {
+        if (authType == AT_Custom && m_customAuth && !m_customAuth->pluginConfig().showSwitchButton) {
             btn->setVisible(false);
         }
     }
@@ -924,11 +925,15 @@ void SFAWidget::replaceWidget(AuthModule *authModule)
     } else {
         m_lockButton->setEnabled(false);
     }
+
+    setFocusProxy(authModule);
+    // 加入事件循环中处理，否则其它控件的geometry还未设置完成，导致UI显示异常
+    QTimer::singleShot(0, this, &SFAWidget::updateBlurEffectGeometry);
 }
 
 void SFAWidget::onRetryButtonVisibleChanged(bool visible)
 {
-    m_lockButton->setVisible(!visible && !(m_customAuth && AT_Custom == m_currentAuthType && !m_customAuth->showLockButton()));
+    m_lockButton->setVisible(!visible && !(m_customAuth && AT_Custom == m_currentAuthType && !m_customAuth->pluginConfig().showLockButton));
     m_retryButton->setVisible(visible);
 }
 
@@ -938,6 +943,8 @@ void SFAWidget::setBioAuthStateVisible(AuthModule *authModule, bool visible)
     m_bioAuthStatePlaceHolder->changeSize(0, (visible || !hasBioAuth) ? 0 : BIO_AUTH_STATE_PLACE_HOLDER_HEIGHT);
     if (authModule)
         authModule->setAuthStatueVisible(visible);
+
+    m_mainLayout->invalidate();
 }
 
 /**
@@ -954,9 +961,9 @@ int SFAWidget::getTopSpacing() const
         // 一般自定义的类型控件尺寸都会比较大，尽量保证能够居中显示。
         // 根据头像、用户名、锁屏以及插件自身的高度来计算居中时顶部间隔
         // 这是一个相对比较严格的高度，如果插件还是无法显示完整，或者界面偏下的话，只能插件调整content界面的大小了
-        int height = m_customAuth->showAvatar() ? m_userAvatar->height() + 10 : 0;
-        height += m_customAuth->showUserName() ? m_nameLabel->height() + 10 : 0;
-        height += m_customAuth->showLockButton() ? m_lockButton->height() + 10 : 0;
+        int height = m_customAuth->pluginConfig().showAvatar ? m_userAvatar->height() + 10 : 0;
+        height += m_customAuth->pluginConfig().showUserName ? m_userNameWidget->height() + 10 : 0;
+        height += m_customAuth->pluginConfig().showLockButton ? m_lockButton->height() + 10 : 0;
 
         centerTop = static_cast<int>((topLevelWidget()->geometry().height() - height - m_customAuth->contentSize().height()) / 2);
     }
@@ -966,19 +973,18 @@ int SFAWidget::getTopSpacing() const
     // 需要额外增加的顶部间隔高度 = 屏幕高度*0.35 - 时间控件高度 - 布局间隔 - 生物认证按钮底部间隔
     // - 生物认证切换按钮底部间隔 - 生物认证图标高度(如果有生物认证因子) - 切换验证类型按钮高度（如果认证因子数量大于1)
     int deltaY = topHeight - calcCurrentHeight(LOCK_CONTENT_CENTER_LAYOUT_MARGIN)
-            - calcCurrentHeight(LOCK_CONTENT_TOP_WIDGET_HEIGHT)
-            - m_bioBottomSpacingHolder->sizeHint().height()
+            - m_bioBottomSpacingHolder->geometry().height()
             - m_authTypeBottomSpacingHolder->sizeHint().height()
             - ((m_faceAuth || m_fingerprintAuth || m_irisAuth) ? BIO_AUTH_STATE_PLACE_HOLDER_HEIGHT : 0)
-            - (m_authButtons.size() > 1 ? CHOOSE_AUTH_TYPE_BUTTON_BOTTOM_SPACING : 0);
+            - (m_authButtons.size() > 1 ? calcCurrentHeight(CHOOSE_AUTH_TYPE_BUTTON_BOTTOM_SPACING) : 0);
 
     return qMax(15, deltaY);
 }
 
 void SFAWidget::resizeEvent(QResizeEvent *event)
 {
-    updateBlurEffectGeometry();
     updateSpaceItem();
+    QTimer::singleShot(0, this, &SFAWidget::updateBlurEffectGeometry);
 
     AuthWidget::resizeEvent(event);
 }
@@ -997,6 +1003,10 @@ void SFAWidget::updateSpaceItem()
         m_bioBottomSpacingHolder->changeSize(0, 0);
         m_bioAuthStatePlaceHolder->changeSize(0, 0);
     }
+    // QSpacerItem 调用了changeSize后需要其所属的layout调用一下invalidate，详见是qt的说明:
+    // Note that if changeSize() is called after the spacer item has been added to a layout,
+    // it is necessary to invalidate the layout in order for the spacer item's new size to take effect.
+    m_mainLayout->invalidate();
 
     emit updateParentLayout();
 }
@@ -1006,7 +1016,7 @@ void SFAWidget::updateFocus()
     for (int i = 0; i < m_mainLayout->layout()->count(); ++i) {
         AuthModule *authModule = qobject_cast<AuthModule *>(m_mainLayout->layout()->itemAt(i)->widget());
         if (authModule && authModule->authType() == m_chooseAuthButtonBox->checkedId()) {
-            if (authModule->authType() == AT_Custom && m_customAuth && !m_customAuth->showSwithButton()) {
+            if (authModule->authType() == AT_Custom && m_customAuth && !m_customAuth->pluginConfig().showSwitchButton) {
                 return;
             }
             setFocus();
@@ -1032,9 +1042,9 @@ void SFAWidget::updateBlurEffectGeometry()
     if (m_customAuth && AT_Custom == m_currentAuthType) {
         QRect rect = this->rect();
         // top
-        if (!m_customAuth->showAvatar()) {
-            if (m_customAuth->showUserName()) {
-                rect.setTop(m_nameLabel->geometry().top() - 10);
+        if (!m_customAuth->pluginConfig().showAvatar) {
+            if (m_customAuth->pluginConfig().showUserName) {
+                rect.setTop(m_userNameWidget->geometry().top() - 10);
             } else {
                 rect.setTop(m_customAuth->geometry().top() - 10);
             }
@@ -1043,7 +1053,7 @@ void SFAWidget::updateBlurEffectGeometry()
         }
         // bottom
         if (m_user->expiredState() == User::ExpiredNormal) {
-            if (!m_customAuth->showLockButton()) {
+            if (!m_customAuth->pluginConfig().showLockButton) {
                 rect.setBottom(m_customAuth->geometry().bottom() + 10);
             } else {
                 rect.setBottom(m_lockButton->geometry().top() - 10);
@@ -1060,8 +1070,7 @@ void SFAWidget::updateBlurEffectGeometry()
 
 void SFAWidget::initAccount()
 {
-    qDebug() << "Init switch button of account ";
-
+    qDebug() << "Init switch button of account";
     /* 认证选择按钮 */
     if (m_authButtons.contains(AT_None)) {
         return;
@@ -1086,20 +1095,76 @@ void SFAWidget::initAccount()
 
 void SFAWidget::onRequestChangeAuth(const int authType)
 {
-    qInfo() << Q_FUNC_INFO << "authType" << authType << "m_chooseAuthButtonBox->isEnabled()" << m_chooseAuthButtonBox->isEnabled()
-               << "m_currentAuthType" << m_currentAuthType;
+    qInfo() << Q_FUNC_INFO
+            << ", authType" << authType
+            << ", chooseAuthButtonBox is enabled" << m_chooseAuthButtonBox->isEnabled()
+            << ", current authentication type" << m_currentAuthType;
 
     if (!m_chooseAuthButtonBox->isEnabled()) {
+        qWarning() << "Authentication button box is disabled";
         return;
     }
 
     if (!m_authButtons.contains(authType)) {
-        qDebug() << "onRequestChangeAuth no contain";
+        qWarning() << "Authentication buttons do not contain the type";
         m_chooseAuthButtonBox->button(m_authButtons.firstKey())->toggled(true);
         return ;
     }
 
     QAbstractButton *btn = m_chooseAuthButtonBox->button(authType);
-    if (btn)
-        emit btn->toggled(true);
+    if (!btn) {
+        qWarning() << "The button of authentication is null";
+        return;
+    }
+
+    emit btn->toggled(true);
+}
+
+bool SFAWidget::useCustomAuth() const
+{
+    // 无密码登录或者自动登录不使用自定义认证
+    const bool isNoPasswordLoginEnabled = m_model->appType() == AuthCommon::Lock         ||
+                             ( m_model ->appType() == AuthCommon::Login       &&
+                               !m_model->currentUser()->isNoPasswordLogin()   &&
+                               !m_model->currentUser()->isAutomaticLogin());
+    if (!isNoPasswordLoginEnabled) {
+        qInfo() << "Automatic login is enabled";
+        return false;
+    }
+
+    // 是否加载了认证插件
+    const QList<dss::module::BaseModuleInterface *> interfaces = dss::module::ModulesLoader::instance().findModulesByType(dss::module::BaseModuleInterface::LoginType).values();
+    if (interfaces.isEmpty()) {
+        qInfo() << "There is no login plugin";
+        return false;
+    }
+
+    dss::module::LoginModuleInterface * const module = dynamic_cast<dss::module::LoginModuleInterface *>(interfaces.first());
+
+    // 当前插件是否启动，由插件自己决定
+    if (!AuthCustom::isPluginEnabled(module)) {
+        qInfo() << "Plugin is disabled";
+        return false;
+    }
+
+    // 判断认证插件是否支持"..."用户
+    if (m_user && m_user->type() == User::Default) {
+        const bool supportDefaultUser = AuthCustom::supportDefaultUser(module);
+        if (!supportDefaultUser) {
+            qInfo() << "Do not support default user";
+            return false;
+        }
+    }
+
+    return true;
+}
+
+void SFAWidget::onActiveAuth(int authType)
+{
+    if (m_currentAuthType != authType) {
+        qWarning() << "Active authentication mismatch the current authentication type";
+        return;
+    }
+
+    emit requestStartAuthentication(m_model->currentUser()->name(), authType);
 }
