@@ -50,6 +50,7 @@ protected:
 
 protected Q_SLOTS:
     void updateBlurEffectGeometry();
+    void onActiveAuth(int authType);
 
 private:
     void initUI();
@@ -71,6 +72,7 @@ private:
     void updateSpaceItem();
     void updateFocus();
     void initAccount();
+    bool useCustomAuth() const;
 
 private:
     QVBoxLayout *m_mainLayout;
