@@ -18,6 +18,9 @@ const QStringList shortTimeFormat = { "h:mm", "hh:mm"};
 
 TimeWidget::TimeWidget(QWidget *parent)
     : QWidget(parent)
+    , m_timeLabel(nullptr)
+    , m_dateLabel(nullptr)
+    , m_refreshTimer(nullptr)
     , m_use24HourFormat(true)
 {
     QFont timeFont;
@@ -115,3 +118,8 @@ void TimeWidget::setShortTimeFormat(int type)
     m_shortTimeIndex = type;
     refreshTime();
 }
+
+QSize TimeWidget::sizeHint() const
+{
+    return QSize(QWidget::sizeHint().width(), m_dateLabel->fontMetrics().height() + m_timeLabel->fontMetrics().height());
+}
